@@ -12,6 +12,20 @@ Contents
 Functions
 ----------
 
+Custom iterators:
+
+.. autosummary::
+   :toctree: generated/
+
+   cyclic_pairs
+
+Array functions:
+
+.. autosummary::
+   :toctree: generated/
+
+   rezero_array
+
 Meta functions:
 
 .. autosummary::
@@ -54,10 +68,12 @@ Sub-packages
 
 * atoms (:mod:`sknano.core.atoms`)
 * math (:mod:`sknano.core.math`)
+* physics (:mod:`sknano.core.physics`)
 * refdata (:mod:`sknano.core.refdata`)
 
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, \
+    unicode_literals
 __docformat__ = 'restructuredtext en'
 
 from ._extras import *
