@@ -10,12 +10,16 @@ An "eXtended" `Atom` class for structure analysis.
 
 """
 from __future__ import absolute_import, division, print_function
+from six.moves import zip
+
 __docformat__ = 'restructuredtext en'
 
+from collections import OrderedDict
 from functools import total_ordering
 import numbers
 import numpy as np
 
+from sknano.core import xyz
 from sknano.core.math import Point, Vector
 from ._atom import Atom
 
@@ -49,7 +53,8 @@ class XAtom(Atom):
 
     """
     _atomattrs = Atom._atomattrs + \
-        ['atomID', 'moleculeID', 'atomtype', 'q', 'v', 'vx', 'vy', 'vz',
+        ['atomID', 'moleculeID', 'atomtype', 'q', 'dr',
+         'r', 'x', 'y', 'z', 'v', 'vx', 'vy', 'vz',
          'f', 'fx', 'fy', 'fz', 'n', 'nx', 'ny', 'nz']
 
     __hash__ = Atom.__hash__
@@ -61,7 +66,11 @@ class XAtom(Atom):
         if m is None and mass is not None:
             m = mass
 
-        super(XAtom, self).__init__(element=element, m=m, x=x, y=y, z=z)
+        super(XAtom, self).__init__(element=element, m=m)
+
+        self.r = Vector([x, y, z])
+        #self._p0 = Point([x, y, z])
+        self.dr = Vector(np.zeros(3), p0=[x, y, z])
 
         self._v = Vector([vx, vy, vz])
         self._f = Vector([fx, fy, fz])
@@ -180,6 +189,154 @@ class XAtom(Atom):
     def mass(self, value):
         self.m = value
 
+    @property
+    def x(self):
+        """:math:`x`-coordinate in units of **Angstroms**.
+
+        Returns
+        -------
+        float
+            :math:`x`-coordinate in units of **Angstroms**.
+
+        """
+        return self._r.x
+
+    @x.setter
+    def x(self, value):
+        """Set `Atom` :math:`x`-coordinate in units of **Angstroms**.
+
+        Parameters
+        ----------
+        value : float
+            :math:`x`-coordinate in units of **Angstroms**.
+
+        """
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self._r.x = value
+
+    @property
+    def y(self):
+        """:math:`y`-coordinate in units of **Angstroms**.
+
+        Returns
+        -------
+        float
+            :math:`y`-coordinate in units of **Angstroms**.
+
+        """
+        return self._r.y
+
+    @y.setter
+    def y(self, value):
+        """Set `Atom` :math:`y`-coordinate in units of **Angstroms**.
+
+        Parameters
+        ----------
+        value : float
+            :math:`y`-coordinate in units of **Angstroms**.
+
+        """
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self._r.y = value
+
+    @property
+    def z(self):
+        """:math:`z`-coordinate in units of **Angstroms**.
+
+        Returns
+        -------
+        float
+            :math:`z`-coordinate in units of **Angstroms**.
+
+        """
+        return self._r.z
+
+    @z.setter
+    def z(self, value):
+        """Set `Atom` :math:`z`-coordinate in units of **Angstroms**.
+
+        Parameters
+        ----------
+        value : float
+            :math:`z`-coordinate in units of **Angstroms**.
+
+        """
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self._r.z = value
+
+    @property
+    def r(self):
+        """:math:`x, y, z` components of `Atom` position vector.
+
+        Returns
+        -------
+        ndarray
+            3-element ndarray of [:math:`x, y, z`] coordinates of `Atom`.
+
+        """
+        return self._r
+
+    @r.setter
+    def r(self, value):
+        """Set :math:`x, y, z` components of `Atom` position vector.
+
+        Parameters
+        ----------
+        value : array_like
+            :math:`x, y, z` coordinates of `Atom` position vector relative to
+            the origin.
+
+        """
+        if not isinstance(value, (list, np.ndarray)):
+            raise TypeError('Expected an array_like object')
+        self._r = Vector(value)
+
+    @property
+    def dr(self):
+        """:math:`x, y, z` components of `Atom` displacement vector.
+
+        Returns
+        -------
+        ndarray
+            3-element ndarray of [:math:`x, y, z`] coordinates of `Atom`.
+
+        """
+        return self._dr
+
+    @dr.setter
+    def dr(self, value):
+        """Set :math:`x, y, z` components of `Atom` displacement vector.
+
+        Parameters
+        ----------
+        value : array_like
+            :math:`x, y, z` components of `Atom` displacement vector.
+
+        """
+        if not isinstance(value, (list, np.ndarray)):
+            raise TypeError('Expected an array_like object')
+        self._dr = Vector(value)
+
+    def get_coords(self, asdict=False):
+        """Return atom coords.
+
+        Parameters
+        ----------
+        asdict : bool, optional
+
+        Returns
+        -------
+        coords : :class:`python:~collections.OrderedDict` or ndarray
+
+        """
+        if asdict:
+            return OrderedDict(list(zip(xyz, self.r)))
+        else:
+            return self.r
+
     @property
     def nx(self):
         """:math:`n_x` image flag.
@@ -471,10 +628,64 @@ class XAtom(Atom):
             raise TypeError('Expected an array_like object')
         self._f = Vector(value)
 
+    def rezero(self, epsilon=1.0e-10):
+        """Re-zero position vector components.
+
+        Set position vector components with absolute value less than
+        `epsilon` to zero.
+
+        Parameters
+        ----------
+        epsilon : float
+            smallest allowed absolute value of any :math:`x,y,z` component.
+
+        """
+        self._r.rezero(epsilon=epsilon)
+
+    def rezero_coords(self, epsilon=1.0e-10):
+        """Alias for :meth:`Atom.rezero`."""
+        self.rezero(epsilon=epsilon)
+
+    def rotate(self, angle=None, rot_axis=None, anchor_point=None,
+               rot_point=None, from_vector=None, to_vector=None, deg2rad=False,
+               transform_matrix=None, verbose=False):
+        """Rotate `Atom` position vector.
+
+        Parameters
+        ----------
+        angle : float
+        rot_axis : :class:`~sknano.core.math.Vector`, optional
+        anchor_point : :class:`~sknano.core.math.Point`, optional
+        rot_point : :class:`~sknano.core.math.Point`, optional
+        from_vector, to_vector : :class:`~sknano.core.math.Vector`, optional
+        deg2rad : bool, optional
+        transform_matrix : :class:`~numpy:numpy.ndarray`
+
+        """
+        self.r.rotate(angle=angle, rot_axis=rot_axis,
+                      anchor_point=anchor_point,
+                      rot_point=rot_point, from_vector=from_vector,
+                      to_vector=to_vector, transform_matrix=transform_matrix,
+                      deg2rad=deg2rad, verbose=verbose)
+
+    def translate(self, t, fix_anchor_point=True):
+        """Translate `Atom` position vector by :class:`Vector` `t`.
+
+        Parameters
+        ----------
+        t : :class:`Vector`
+        fix_anchor_point : bool, optional
+
+        """
+        #TODO compare timing benchmarks for translation of position vector.
+        self.r.translate(t, fix_anchor_point=fix_anchor_point)
+        #self.r += t
+
     def todict(self):
         return dict(element=self.element, atomID=self.atomID,
                     moleculeID=self.moleculeID, atomtype=self.atomtype,
-                    q=self.q, mass=self.mass, x=self.x, y=self.y, z=self.z,
+                    q=self.q, mass=self.mass,
+                    x=self.x, y=self.y, z=self.z,
                     vx=self.vx, vy=self.vy, vz=self.vz,
                     fx=self.fx, fy=self.fy, fz=self.fz,
                     nx=self.nx, ny=self.ny, nz=self.nz)
