@@ -8,6 +8,7 @@ Math helper functions (:mod:`sknano.core._extras`)
 
 """
 from __future__ import absolute_import, division, print_function
+from six.moves import range
 __docformat__ = 'restructuredtext en'
 
 from fractions import gcd
@@ -56,7 +57,7 @@ def totient_func(n=int):
     n = int(n)
 
     tots = 0
-    for k in xrange(1, n + 1):
+    for k in range(1, n + 1):
         if gcd(n, k) == 1:
             tots += 1
 
