@@ -2,7 +2,7 @@
 from __future__ import division, print_function, absolute_import
 
 
-def configuration(parent_package='', top_path=None):
+def configuration(parent_package='core', top_path=None):
     from numpy.distutils.misc_util import Configuration
     config = Configuration('units', parent_package, top_path)
     return config
